package cn.com.infosec.asn1;

import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;

public class DEROutputStream extends FilterOutputStream implements DERTags {
   public DEROutputStream(OutputStream os) {
      super(os);
   }

   private void writeLength(int length) {
      if (length > 127) {
         int var2 = 1;

         for(int var3 = length; (var3 >>>= 8) != 0; ++var2) {
         }

         this.write((byte)(var2 | 128));

         for(var2 = (var2 - 1) * 8; var2 >= 0; var2 -= 8) {
            this.write((byte)(length >> var2));
         }
      } else {
         this.write((byte)length);
      }

   }

   void writeEncoded(int tag, byte[] bytes) {
      this.write(tag);
      this.writeLength(bytes.length);
      this.write(bytes);
   }

   void writeEncodedHigh(int leadingOctet, int tag, byte[] bytes) {
      this.write(leadingOctet);
      this.write(tag);
      this.writeLength(bytes.length);
      this.write(bytes);
   }

   protected void writeNull() {
      this.write(5);
      this.write(0);
   }

   public void write(byte[] buf) {
      super.out.write(buf, 0, buf.length);
   }

   public void write(byte[] buf, int offSet, int len) {
      super.out.write(buf, offSet, len);
   }

   public void writeObject(Object obj) {
      if (obj == null) {
         this.writeNull();
      } else if (obj instanceof DERObject) {
         ((DERObject)obj).encode(this);
      } else {
         if (!(obj instanceof DEREncodable)) {
            throw new IOException("object not DEREncodable");
         }

         ((DEREncodable)obj).getDERObject().encode(this);
      }

   }
}
